==> nezha-compute-common-1.25.14-20180904.050355-1-sources.jar: cn/com/duiba/nezha/compute/common/model/pacing/OrientInfo.java <==
package cn.com.duiba.nezha.compute.common.model.pacing;

public class OrientInfo {

    Long advertId;
    Long orientId;
    boolean isManagered; //是否为托管配置
    Integer chargeType;  //计费方式
    Long target = 0l;       //目标成本
    Long fee = 0l; //出价
    Double cvr=0.0;
    Double confidence=0.0;   //置信度
    Double bias=3.0;         //偏差
    Double orientCostG1d = 0.0;             //配置全局1天消耗
    Double orientCostG7d = 0.0;             //配置全局7天消耗
    Double orientClkG1d=0.0;               //配置点击
    Double orientCvrG1d=0.0;               //配置cvr


    public OrientInfo() {
    }

    public OrientInfo(Long advertId, Long orientId, boolean isManagered, Integer chargeType, Long target, Long fee, Double cvr, Double confidence, Double bias, Double orientCostG1d, Double orientCostG7d, Double orientClkG1d, Double orientCvrG1d) {
        this.advertId = advertId;
        this.orientId = orientId;
        this.isManagered = isManagered;
        this.chargeType = chargeType;
        this.target = target;
        this.fee = fee;
        this.cvr = cvr;
        this.confidence = confidence;
        this.bias = bias;
        this.orientCostG1d = orientCostG1d;
        this.orientCostG7d = orientCostG7d;
        this.orientClkG1d = orientClkG1d;
        this.orientCvrG1d = orientCvrG1d;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public boolean isManagered() {
        return isManagered;
    }

    public void setManagered(boolean managered) {
        isManagered = managered;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Long getTarget() {
        return target;
    }

    public void setTarget(Long target) {
        this.target = target;
    }

    public Long getFee() {
        return fee;
    }

    public void setFee(Long fee) {
        this.fee = fee;
    }

    public Double getCvr() {
        return cvr;
    }

    public void setCvr(Double cvr) {
        this.cvr = cvr;
    }

    public Double getConfidence() {
        return confidence;
    }

    public void setConfidence(Double confidence) {
        this.confidence = confidence;
    }

    public Double getBias() {
        return bias;
    }

    public void setBias(Double bias) {
        this.bias = bias;
    }

    public Double getOrientCostG1d() {
        return orientCostG1d;
    }

    public void setOrientCostG1d(Double orientCostG1d) {
        this.orientCostG1d = orientCostG1d;
    }

    public Double getOrientCostG7d() {
        return orientCostG7d;
    }

    public void setOrientCostG7d(Double orientCostG7d) {
        this.orientCostG7d = orientCostG7d;
    }

    public Double getOrientClkG1d() {
        return orientClkG1d;
    }

    public void setOrientClkG1d(Double orientClkG1d) {
        this.orientClkG1d = orientClkG1d;
    }

    public Double getOrientCvrG1d() {
        return orientCvrG1d;
    }

    public void setOrientCvrG1d(Double orientCvrG1d) {
        this.orientCvrG1d = orientCvrG1d;
    }
}

==> nezha-compute-common-1.26.5-20181010.031909-1-sources.jar: cn/com/duiba/nezha/compute/common/model/pacing/OrientInfo.java <==
package cn.com.duiba.nezha.compute.common.model.pacing;

public class OrientInfo {

    Long advertId;
    Long orientId;
    boolean isManagered; //是否为托管配置
    Integer chargeType;  //计费方式
    Long target = 0l;       //目标成本
    Long fee = 0l; //出价
    Double cvr = 0.0;
    Double confidence = 0.0;   //置信度
    Double bias = 3.0;         //偏差
    Double orientCostG1d = 0.0;             //配置全局1天消耗
    Double orientCostG7d = 0.0;             //配置全局7天消耗
    Double orientClkG1d = 0.0;               //配置点击
    Double orientCvrG1d = 0.0;               //配置cvr
    Double slotOrientationCost;               //广告位+配置粒度消耗
    Double slotOrientationConvert;               //广告位+配置粒度转化量

    public OrientInfo() {
    }

    public OrientInfo(Long advertId, Long orientId, boolean isManagered, Integer chargeType, Long target, Long fee, Double cvr, Double confidence, Double bias, Double orientCostG1d, Double orientCostG7d, Double orientClkG1d, Double orientCvrG1d, Double slotOrientationCost, Double slotOrientationConvert) {
        this.advertId = advertId;
        this.orientId = orientId;
        this.isManagered = isManagered;
        this.chargeType = chargeType;
        this.target = target;
        this.fee = fee;
        this.cvr = cvr;
        this.confidence = confidence;
        this.bias = bias;
        this.orientCostG1d = orientCostG1d;
        this.orientCostG7d = orientCostG7d;
        this.orientClkG1d = orientClkG1d;
        this.orientCvrG1d = orientCvrG1d;
        this.slotOrientationCost = slotOrientationCost;
        this.slotOrientationConvert = slotOrientationConvert;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public boolean isManagered() {
        return isManagered;
    }

    public void setManagered(boolean managered) {
        isManagered = managered;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Long getTarget() {
        return target;
    }

    public void setTarget(Long target) {
        this.target = target;
    }

    public Long getFee() {
        return fee;
    }

    public void setFee(Long fee) {
        this.fee = fee;
    }

    public Double getCvr() {
        return cvr;
    }

    public void setCvr(Double cvr) {
        this.cvr = cvr;
    }

    public Double getConfidence() {
        return confidence;
    }

    public void setConfidence(Double confidence) {
        this.confidence = confidence;
    }

    public Double getBias() {
        return bias;
    }

    public void setBias(Double bias) {
        this.bias = bias;
    }

    public Double getOrientCostG1d() {
        return orientCostG1d;
    }

    public void setOrientCostG1d(Double orientCostG1d) {
        this.orientCostG1d = orientCostG1d;
    }

    public Double getOrientCostG7d() {
        return orientCostG7d;
    }

    public void setOrientCostG7d(Double orientCostG7d) {
        this.orientCostG7d = orientCostG7d;
    }

    public Double getOrientClkG1d() {
        return orientClkG1d;
    }

    public void setOrientClkG1d(Double orientClkG1d) {
        this.orientClkG1d = orientClkG1d;
    }

    public Double getOrientCvrG1d() {
        return orientCvrG1d;
    }

    public void setOrientCvrG1d(Double orientCvrG1d) {
        this.orientCvrG1d = orientCvrG1d;
    }

    public Double getSlotOrientationCost() {
        return slotOrientationCost;
    }

    public void setSlotOrientationCost(Double slotOrientationCost) {
        this.slotOrientationCost = slotOrientationCost;
    }

    public Double getSlotOrientationConvert() {
        return slotOrientationConvert;
    }

    public void setSlotOrientationConvert(Double slotOrientationConvert) {
        this.slotOrientationConvert = slotOrientationConvert;
    }
}
